@@ -94,7 +94,7 @@ class LobbyMemberTransaction:
         if result != Result.ok:
             raise get_exception(result)
 
-    def DeleteMetadata(self, key: str) -> None:
+    def delete_metadata(self, key: str) -> None:
         """
         Sets metadata value under a given key name for the current user.
         """
@@ -180,7 +180,7 @@ class LobbyManager:
             sdk.IDiscordLobbyEvents,
             self._on_lobby_update,
             self._on_lobby_delete,
-            self._on_member_connet,
+            self._on_member_connect,
             self._on_member_update,
             self._on_member_disconnect,
             self._on_lobby_message,
@@ -194,7 +194,7 @@ class LobbyManager:
     def _on_lobby_delete(self, event_data, lobby_id, reason):
         self.on_lobby_delete(lobby_id, reason)
 
-    def _on_member_connet(self, event_data, lobby_id, user_id):
+    def _on_member_connect(self, event_data, lobby_id, user_id):
         self.on_member_connect(lobby_id, user_id)
 
     def _on_member_update(self, event_data, lobby_id, user_id):
@@ -387,7 +387,7 @@ class LobbyManager:
         lobby_secret = sdk.DiscordLobbySecret()
 
         result = self._internal.get_lobby_activity_secret(self._internal, lobby_id, lobby_secret)
-        if result != result.ok:
+        if result != Result.ok:
             raise get_exception(result)
 
         return lobby_secret.value.decode("utf8")
@@ -424,7 +424,7 @@ class LobbyManager:
         """
         Returns the number of metadata key/value pairs on a given lobby.
         """
-        count = sdk.c_int32()
+        count = ctypes.c_int32()
 
         result = Result(self._internal.lobby_metadata_count(self._internal, lobby_id, count))
         if result != Result.ok:
@@ -473,7 +473,7 @@ class LobbyManager:
         """
         Get the number of members in a lobby.
         """
-        count = sdk.c_int32()
+        count = ctypes.c_int32()
 
         result = Result(self._internal.member_count(self._internal, lobby_id, count))
         if result != Result.ok:
@@ -509,7 +509,7 @@ class LobbyManager:
         """
         Gets the number of metadata key/value pairs for the given lobby member.
         """
-        count = sdk.c_int32()
+        count = ctypes.c_int32()
 
         result = Result(self._internal.member_metadata_count(
             self._internal,
@@ -650,7 +650,7 @@ class LobbyManager:
         """
         Get the number of lobbies that match the search.
         """
-        count = sdk.c_int32()
+        count = ctypes.c_int32()
         self._internal.lobby_count(self._internal, count)
         return count.value
 
